@@ -64,11 +64,11 @@ class NotificationManagerMock:
     def __init__(self, resource_name: str, logger=None):
         pass
 
-    def stage(self, event_type: str, message, group_id: str):
+    def stage(self, event_type: str, message, group_id: str, event_cause: str = None):
         pass
 
     def flush(self):
         pass
 
-    def publish(self, event_type: str, message, group_id: str):
+    def publish(self, event_type: str, message, group_id: str, event_cause: str = None):
         pass
